@@ -4,7 +4,7 @@ import logging
 import numpy as np
 import spacy
 
-from .constants import LANG, LANGS
+from qary.config import LANG, LANGS
 
 
 log = logging.getLogger(__name__)
@@ -125,3 +125,8 @@ class SpacyLM:
 
 
 nlp = load(LANG)
+
+
+def tokenize(s):
+    global nlp
+    return [tok.text for tok in nlp(s)]
